from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
import uuid

class MenuBase(BaseModel):
    name: str = Field(..., description="Menu name")
    description: Optional[str] = Field(None, description="Menu description")
    category: Optional[str] = Field(None, description="Menu category")
    price: int = Field(..., description="Menu price")

class MenuCreate(MenuBase):
    pass

class MenuUpdate(MenuBase):
    name: Optional[str] = Field(None, description="Menu name")
    description: Optional[str] = Field(None, description="Menu description")
    category: Optional[str] = Field(None, description="Menu category")
    price: Optional[int] = Field(None, description="Menu price")

class MenuSchema(MenuBase):
    id: uuid.UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True